@@ -319,7 +319,7 @@ class NetworkInterface:
     ) -> Tuple[
         str,
         Dict[int, Dict[Tuple[Optional[int], int], Mapping[str, Any]]],
-        socket.socket
+        socket.socket,
     ]:
         path, configuration, fd = await self._interface.call_attach_fd(
             app_defined_root, token
@@ -420,7 +420,7 @@ class NodeInterface:
             if name == "IvIndex":
                 sig = self.iv_index.signal
             elif name == "IvUpdate":
-                sig = self.iv_udpate.signal
+                sig = self.iv_update.signal
             elif name == "IvState":
                 sig = self.iv_state.signal
                 val = IvState(variant.value)
